==> claromentis-framework-9.6.6-26891208.zip: web/intranet/core/classes/ORM/EntityMap.php <==
<?php
namespace Claromentis\Core\ORM;

$GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"] ?: array()) + array("_1f0784f4a57c" . "1cde319065969" . "677bf3d" => base64_decode("ZGVidWdfYmFja3" . "RyYWNl"), "_3a1d32b00c281a9ae859aa" . "88201be7c9" => base64_decode("ZnV" . "uY3" . "Rpb" . "24="));
use Analogue\ORM\Relationships\HasMany as AnalogueHasMany;
use Analogue\ORM\System\Manager;




class EntityMap extends \Analogue\ORM\EntityMap
{
    
    
    
    
    public function hasMany($_ba1f6e266e3ebd29f620349be8ec92a5, string $_69fafbdb2ab3bbd9e8db801e9b1d5aa2, string $_4c521d12a421e1ecc509801cfc0380aa = null, string $_17c811a92d7edf64dffb9cbf24882bdd = null) : AnalogueHasMany
    {
        
        
        [, $_1ea23b8f088d7a05fe5d285df5b5dd30] = $GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"]["_1f0784f4a5" . "7c1cde31906" . "5969677bf3d"](false);
        $_2fc7dcae09ab225f57e35d0eb8189eeb = $_1ea23b8f088d7a05fe5d285df5b5dd30[$GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"]["_3a1d32b00c281a9ae859aa8" . "8201be7c9"]];
        $this->relatedClasses[$_2fc7dcae09ab225f57e35d0eb8189eeb] = $_69fafbdb2ab3bbd9e8db801e9b1d5aa2;
        $this->addManyRelation($_2fc7dcae09ab225f57e35d0eb8189eeb);
        $this->addForeignRelation($_2fc7dcae09ab225f57e35d0eb8189eeb);
        
        
        $_4c521d12a421e1ecc509801cfc0380aa = $_4c521d12a421e1ecc509801cfc0380aa ?: $this->getForeignKey();
        $_f9e97a4a9c44a2fafef5ff1c58ff6e8c = Manager::getInstance()->mapper($_69fafbdb2ab3bbd9e8db801e9b1d5aa2);
        $_17c811a92d7edf64dffb9cbf24882bdd = $_17c811a92d7edf64dffb9cbf24882bdd ?: $this->getKeyName();
        
        
        return new Analogue\Relationships\HasMany($_f9e97a4a9c44a2fafef5ff1c58ff6e8c, $_ba1f6e266e3ebd29f620349be8ec92a5, $_4c521d12a421e1ecc509801cfc0380aa, $_17c811a92d7edf64dffb9cbf24882bdd);
    }
}

==> claromentis-framework-10.3.3-59629072.zip: web/intranet/core/classes/ORM/EntityMap.php <==
<?php
namespace Claromentis\Core\ORM;

$GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"] ?: array()) + array("_3a1d32b00c281a9ae859aa88201be7c" . "9" => base64_decode("ZnVuY3Rpb2" . "4="), "_1f0784f4a57c1cde319" . "065969677bf3d" => base64_decode("ZGVidWdf" . "YmFja3Ry" . "YWNl"));
use Analogue\ORM\Relationships\HasMany as AnalogueHasMany;
use Analogue\ORM\System\Manager;




class EntityMap extends \Analogue\ORM\EntityMap
{
    
    
    
    
    public function hasMany($_ba1f6e266e3ebd29f620349be8ec92a5, string $_69fafbdb2ab3bbd9e8db801e9b1d5aa2, string $_4c521d12a421e1ecc509801cfc0380aa = null, string $_17c811a92d7edf64dffb9cbf24882bdd = null) : AnalogueHasMany
    {
        
        
        [, $_1ea23b8f088d7a05fe5d285df5b5dd30] = $GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"]["_1f0784f4" . "a57c1cde3" . "190659696" . "77bf3d"](false);
        $_2fc7dcae09ab225f57e35d0eb8189eeb = $_1ea23b8f088d7a05fe5d285df5b5dd30[$GLOBALS["__65da1b1ec2d6653e8a0ab784" . "8e536215"]["_3a1d32b00c281" . "a9ae859aa88201" . "be7c9"]];
        $this->relatedClasses[$_2fc7dcae09ab225f57e35d0eb8189eeb] = $_69fafbdb2ab3bbd9e8db801e9b1d5aa2;
        $this->addManyRelation($_2fc7dcae09ab225f57e35d0eb8189eeb);
        $this->addForeignRelation($_2fc7dcae09ab225f57e35d0eb8189eeb);
        
        
        $_4c521d12a421e1ecc509801cfc0380aa = $_4c521d12a421e1ecc509801cfc0380aa ?: $this->getForeignKey();
        $_f9e97a4a9c44a2fafef5ff1c58ff6e8c = Manager::getInstance()->mapper($_69fafbdb2ab3bbd9e8db801e9b1d5aa2);
        $_17c811a92d7edf64dffb9cbf24882bdd = $_17c811a92d7edf64dffb9cbf24882bdd ?: $this->getKeyName();
        
        
        return new Analogue\Relationships\HasMany($_f9e97a4a9c44a2fafef5ff1c58ff6e8c, $_ba1f6e266e3ebd29f620349be8ec92a5, $_4c521d12a421e1ecc509801cfc0380aa, $_17c811a92d7edf64dffb9cbf24882bdd);
    }
}
